#ifndef NT2_INCLUDE_FUNCTIONS_GROUP_HPP_INCLUDED
#define NT2_INCLUDE_FUNCTIONS_GROUP_HPP_INCLUDED

#include <nt2/swar/include/functions/group.hpp>

#endif
